"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = __importDefault(require("crypto"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const ngrv_1 = require("./ngrv");
const rootDir = process.cwd();
const builtAtFile = ngrv_1.defaultOptions.builtAtFile;
const commitHashFile = ngrv_1.defaultOptions.commitHashFile;
const directory = '.ngrv';
const getRandomString = (size = 8) => crypto_1.default.randomBytes(size).toString('hex');
beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
    fs_1.default.rmSync(path_1.default.join(rootDir, builtAtFile), { recursive: true, force: true });
    fs_1.default.rmSync(path_1.default.join(rootDir, commitHashFile), { recursive: true, force: true });
    fs_1.default.rmSync(path_1.default.join(rootDir, directory), { recursive: true, force: true });
}));
test('should be able to read the engrave', () => __awaiter(void 0, void 0, void 0, function* () {
    (0, ngrv_1.engrave)();
    const builtAtPath = path_1.default.join(rootDir, builtAtFile);
    const builtAt = fs_1.default.readFileSync(builtAtPath, 'utf8');
    expect(new Date(builtAt)).not.toBe('Invalid Date');
    expect(new Date(builtAt)).toBeInstanceOf(Date);
    const commitHashPath = path_1.default.join(rootDir, commitHashFile);
    const commitHash = fs_1.default.readFileSync(commitHashPath, 'utf8');
    expect(commitHash).toHaveLength(40);
    expect(commitHash).toBeDefined();
    expect(commitHash).toMatch(/^[0-9a-f]{40}$/);
    (0, ngrv_1.readEngrave)({ silent: true });
    expect(typeof process.env[builtAtFile]).toBe('string');
    expect(typeof process.env[commitHashFile]).toBe('string');
    expect(process.env[builtAtFile]).toBe(builtAt);
    expect(process.env[commitHashFile]).toBe(commitHash);
}));
test('should be configurable fixture location', () => __awaiter(void 0, void 0, void 0, function* () {
    const builtAtFile = 'BUILT_AT_' + getRandomString();
    const commitHashFile = 'COMMIT_HASH_' + getRandomString();
    (0, ngrv_1.engrave)({ directory, builtAtFile, commitHashFile });
    const builtAtPath = path_1.default.join(rootDir, directory, builtAtFile);
    const builtAt = fs_1.default.readFileSync(builtAtPath, 'utf8');
    expect(new Date(builtAt)).not.toBe('Invalid Date');
    expect(new Date(builtAt)).toBeInstanceOf(Date);
    const commitHashPath = path_1.default.join(rootDir, directory, commitHashFile);
    const commitHash = fs_1.default.readFileSync(commitHashPath, 'utf8');
    expect(commitHash).toHaveLength(40);
    expect(commitHash).toBeDefined();
    expect(commitHash).toMatch(/^[0-9a-f]{40}$/);
    (0, ngrv_1.readEngrave)({ directory, builtAtFile, commitHashFile, silent: true });
    expect(typeof process.env[builtAtFile]).toBe('string');
    expect(typeof process.env[commitHashFile]).toBe('string');
    expect(process.env[builtAtFile]).toBe(builtAt);
    expect(process.env[commitHashFile]).toBe(commitHash);
}));
// test('fail to read', async () => {
//   const directory = getRandomString();
//   expect(readEngrave({ directory, silent: true })).toBeUndefined();
//   // expect(readEngrave({ directory, silent: true })).toThrow();
// });
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    fs_1.default.rmSync(path_1.default.join(rootDir, builtAtFile), { recursive: true, force: true });
    fs_1.default.rmSync(path_1.default.join(rootDir, commitHashFile), { recursive: true, force: true });
    fs_1.default.rmSync(path_1.default.join(rootDir, directory), { recursive: true, force: true });
}));
//# sourceMappingURL=ngrv.spec.js.map